@@ -4,7 +4,7 @@
 modname = 'bootstrap'
 distname = 'cubicweb-bootstrap'
 
-numversion = (1, 6, 6)
+numversion = (1, 6, 7)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -15,7 +15,7 @@ web = 'https://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
     'cubicweb': '>= 3.26.0',
-    'six': '>= 1.12.O',
+    'six': '>= 1.12.0',
 }
 __recommends__ = {}
 
